%global sover 3.8

%global forgeurl https://github.com/simbody/simbody
%global date 20230325
%global commit 3c3ad5a50a6fdbf91a72ea3801b52ab43336243f
%global short_commit %(c="%{commit}"; echo ${c:0:7})
%forgemeta

Name:           simbody
Version:        3.7
Release:        %autorelease
Summary:        High-performance C++ multibody dynamics/physics library

License:        Apache-2.0
URL:            %{forgeurl}
Source:         %{forgesource}

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  ninja-build

BuildRequires:  flexiblas-devel
BuildRequires:  doxygen
# optional dependencies
BuildRequires:  freeglut-devel
BuildRequires:  libXi-devel
BuildRequires:  libXmu-devel

%description
Simbody is a high-performance, open-source toolkit for science- and
engineering-quality simulation of articulated mechanisms, including
biomechanical structures such as human and animal skeletons, mechanical systems
like robots, vehicles, and machines, and anything else that can be described as
a set of rigid bodies interconnected by joints, influenced by forces and
motions, and restricted by constraints. Simbody includes a multibody dynamics
library for modeling motion in generalized/internal coordinates in O(n) time.
This is sometimes called a Featherstone-style physics engine.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    doc
The %{name}-doc package contains documentation for %{name}.

%prep
%forgeautosetup -p1

%build
%cmake \
    -GNinja \
    -DCMAKE_BUILD_TYPE=Release \

%cmake_build

%install
%cmake_install

rm %{buildroot}%{_libdir}/cmake/simbody/SampleCMakeLists.txt

%check
# https://kojipkgs.fedoraproject.org//work/tasks/4015/102414015/build.log
%ifarch x86_64
%ctest -E 'TestCustomConstraints'
%elifarch i686
# https://download.copr.fedorainfracloud.org/results/topazus/test-review/fedora-rawhide-i386/06821141-simbody/builder-live.log.gz
%ctest -E 'TestReverseMobilizers'
%else
%ctest
%endif

%files
%license LICENSE.txt
%doc README.md
%{_libdir}/libSimTK*.so.%{sover}
%dir %{_libexecdir}/simbody
%{_libexecdir}/simbody/simbody-visualizer

%files devel
%{_includedir}/simbody/
%{_libdir}/libSimTK*.so
%dir %{_libdir}/cmake/simbody
%{_libdir}/cmake/simbody/*.cmake
%{_libdir}/pkgconfig/simbody.pc

%files doc
%{_datadir}/doc/simbody/
%dir %{_libdir}/simbody
%{_libdir}/simbody/examples/

%changelog
%autochangelog
